/* snapshot-list-row.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from snapshot-list-row.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <cairo.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_SNAPSHOT_LIST_ROW (boxes_snapshot_list_row_get_type ())
#define BOXES_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow))
#define BOXES_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))
#define BOXES_IS_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_IS_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_SNAPSHOT_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))

typedef struct _BoxesSnapshotListRow BoxesSnapshotListRow;
typedef struct _BoxesSnapshotListRowClass BoxesSnapshotListRowClass;
typedef struct _BoxesSnapshotListRowPrivate BoxesSnapshotListRowPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block92Data Block92Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _Block93Data Block93Data;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

struct _BoxesSnapshotListRow {
	GtkListBoxRow parent_instance;
	BoxesSnapshotListRowPrivate * priv;
	GVirDomainSnapshot* snapshot;
};

struct _BoxesSnapshotListRowClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesSnapshotListRowPrivate {
	gchar* _activity_message;
	GtkRevealer* delete_revealer;
	GtkLabel* name_label;
	GtkStack* mode_stack;
	GtkEntry* name_entry;
	GtkBox* edit_name_box;
	GtkBox* show_name_box;
	gint index;
	gint parent_size;
	BoxesLibvirtMachine* machine;
	GtkContainer* parent_container;
};

struct _Block92Data {
	int _ref_count_;
	BoxesSnapshotListRow* self;
	gboolean show_activity;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _Block93Data {
	int _ref_count_;
	Block92Data * _data92_;
	gulong restart_id;
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);

static gpointer boxes_snapshot_list_row_parent_class = NULL;

GType boxes_snapshot_list_row_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_SNAPSHOT_LIST_ROW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowPrivate))
enum  {
	BOXES_SNAPSHOT_LIST_ROW_DUMMY_PROPERTY,
	BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE
};
static void boxes_snapshot_list_row_revert_to_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_snapshot_list_row_rename_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_snapshot_list_row_delete_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
static void __lambda141_ (BoxesSnapshotListRow* self);
static void ___lambda141__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean boxes_snapshot_list_row_real_draw (GtkWidget* base, cairo_t* ct);
static void boxes_snapshot_list_row_on_save_name_button_clicked (BoxesSnapshotListRow* self);
static void _boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block92Data* block92_data_ref (Block92Data* _data92_);
static void block92_data_unref (void * _userdata_);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
void boxes_snapshot_list_row_set_activity_message (BoxesSnapshotListRow* self, const gchar* value);
static Block93Data* block93_data_ref (Block93Data* _data93_);
static void block93_data_unref (void * _userdata_);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ___lambda136_ (Block93Data* _data93_);
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda136__gvir_domain_stopped (GVirDomain* _sender, gpointer self);
static void __lambda137_ (Block92Data* _data92_, GObject* obj, GAsyncResult* res);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda137__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda138_ (BoxesSnapshotListRow* self);
static void ___lambda138__boxes_notification_ok_func (gpointer self);
static void __lambda139_ (BoxesSnapshotListRow* self);
static void __lambda140_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res);
static void ___lambda140__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda139__boxes_notification_cancel_func (gpointer self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
void boxes_snapshot_list_row_unreveal (BoxesSnapshotListRow* self);
void boxes_snapshot_list_row_reveal (BoxesSnapshotListRow* self);
static void boxes_snapshot_list_row_update_index (BoxesSnapshotListRow* self);
const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self);
static GObject * boxes_snapshot_list_row_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_snapshot_list_row___lambda142_ (BoxesSnapshotListRow* self);
static void _boxes_snapshot_list_row_update_index_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void _boxes_snapshot_list_row_update_index_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void __boxes_snapshot_list_row___lambda142__gtk_widget_parent_set (GtkWidget* _sender, GtkWidget* previous_parent, gpointer self);
static void boxes_snapshot_list_row_finalize (GObject* obj);
static void _vala_boxes_snapshot_list_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_snapshot_list_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const GActionEntry BOXES_SNAPSHOT_LIST_ROW_action_entries[3] = {{"revert-to", _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback}, {"rename", _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback}, {"delete", _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback}};

static void _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_revert_to_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 368 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_rename_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 375 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_delete_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 382 "snapshot-list-row.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return self ? g_object_ref (self) : NULL;
#line 389 "snapshot-list-row.c"
}


static void __lambda141_ (BoxesSnapshotListRow* self) {
	GtkRevealer* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->delete_revealer;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gtk_revealer_get_child_revealed (_tmp0_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = _tmp1_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (!_tmp2_) {
#line 405 "snapshot-list-row.c"
		GtkContainer* _tmp3_ = NULL;
		GtkContainer* _tmp4_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		self->priv->parent_container = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = self->priv->parent_container;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (_tmp4_ != NULL) {
#line 416 "snapshot-list-row.c"
			GtkContainer* _tmp5_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
			_tmp5_ = self->priv->parent_container;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
			gtk_container_remove (_tmp5_, (GtkWidget*) self);
#line 422 "snapshot-list-row.c"
		}
	}
}


static void ___lambda141__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	__lambda141_ ((BoxesSnapshotListRow*) self);
#line 431 "snapshot-list-row.c"
}


BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine) {
	BoxesSnapshotListRow * self = NULL;
	GVirDomainSnapshot* _tmp0_ = NULL;
	GVirDomainSnapshot* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	GSimpleActionGroup* action_group = NULL;
	GSimpleActionGroup* _tmp13_ = NULL;
	GtkRevealer* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (snapshot != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = (BoxesSnapshotListRow*) g_object_new (object_type, NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = snapshot;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->snapshot);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->snapshot = _tmp1_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = machine;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->machine);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->machine = _tmp3_;
#line 467 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* _tmp4_ = NULL;
		GVirDomainSnapshot* _tmp5_ = NULL;
		GVirConfigDomainSnapshot* _tmp6_ = NULL;
		GtkLabel* _tmp7_ = NULL;
		GVirConfigDomainSnapshot* _tmp8_ = NULL;
		GVirConfigDomainSnapshot* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = snapshot;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = gvir_domain_snapshot_get_config (_tmp5_, (guint) 0, &_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = _tmp6_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 484 "snapshot-list-row.c"
			goto __catch126_g_error;
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = self->priv->name_label;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = _tmp4_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = _tmp8_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = gvir_config_domain_snapshot_get_description (_tmp9_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_label_set_label (_tmp7_, _tmp10_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp9_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp4_);
#line 503 "snapshot-list-row.c"
	}
	goto __finally126;
	__catch126_g_error:
	{
		GError* e = NULL;
		GError* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = e;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp12_ = _tmp11_->message;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("snapshot-list-row.vala:60: %s", _tmp12_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 523 "snapshot-list-row.c"
	}
	__finally126:
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return NULL;
#line 534 "snapshot-list-row.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = g_simple_action_group_new ();
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	action_group = _tmp13_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_action_map_add_action_entries ((GActionMap*) action_group, BOXES_SNAPSHOT_LIST_ROW_action_entries, G_N_ELEMENTS (BOXES_SNAPSHOT_LIST_ROW_action_entries), self);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_insert_action_group ((GtkWidget*) self, "snap", (GActionGroup*) action_group);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = self->priv->delete_revealer;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object ((GObject*) _tmp14_, "notify::child-revealed", (GCallback) ___lambda141__g_object_notify, self, 0);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (action_group);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return self;
#line 552 "snapshot-list-row.c"
}


BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return boxes_snapshot_list_row_construct (BOXES_TYPE_SNAPSHOT_LIST_ROW, snapshot, machine);
#line 559 "snapshot-list-row.c"
}


static gboolean boxes_snapshot_list_row_real_draw (GtkWidget* base, cairo_t* ct) {
	BoxesSnapshotListRow * self;
	gboolean result = FALSE;
	cairo_t* _tmp0_ = NULL;
	gint height = 0;
	gint _tmp1_ = 0;
	GtkStyleContext* sc = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	gdouble indicator_size = 0.0;
	gint _tmp4_ = 0;
	GtkStyleContext* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GdkRGBA line_color = {0};
	GtkStyleContext* _tmp7_ = NULL;
	GtkStateFlags _tmp8_ = 0;
	GdkRGBA _tmp9_ = {0};
	cairo_t* _tmp10_ = NULL;
	GdkRGBA _tmp11_ = {0};
	gdouble _tmp12_ = 0.0;
	GdkRGBA _tmp13_ = {0};
	gdouble _tmp14_ = 0.0;
	GdkRGBA _tmp15_ = {0};
	gdouble _tmp16_ = 0.0;
	GdkRGBA _tmp17_ = {0};
	gdouble _tmp18_ = 0.0;
	cairo_t* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	gint _tmp27_ = 0;
	gint _tmp28_ = 0;
	gboolean is_current = FALSE;
	gboolean _tmp40_ = FALSE;
	cairo_t* _tmp42_ = NULL;
	GtkStyleContext* _tmp43_ = NULL;
	cairo_t* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	gint _tmp46_ = 0;
	gdouble _tmp47_ = 0.0;
	gdouble _tmp48_ = 0.0;
	GtkStyleContext* _tmp49_ = NULL;
	cairo_t* _tmp50_ = NULL;
	gint _tmp51_ = 0;
	gint _tmp52_ = 0;
	gdouble _tmp53_ = 0.0;
	gdouble _tmp54_ = 0.0;
	cairo_t* _tmp55_ = NULL;
	GtkStyleContext* _tmp56_ = NULL;
	GError * _inner_error_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = (BoxesSnapshotListRow*) base;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (ct != NULL, FALSE);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = ct;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	GTK_WIDGET_CLASS (boxes_snapshot_list_row_parent_class)->draw ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_list_box_row_get_type (), GtkListBoxRow), _tmp0_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gtk_widget_get_allocated_height ((GtkWidget*) self);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	height = _tmp1_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	sc = _tmp3_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = height;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	indicator_size = _tmp4_ / 2.0;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = sc;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_save (_tmp5_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp6_ = sc;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_add_class (_tmp6_, "indicator");
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp7_ = sc;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = gtk_widget_get_state_flags ((GtkWidget*) self);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_get_background_color (_tmp7_, _tmp8_, &_tmp9_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	line_color = _tmp9_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = ct;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp11_ = line_color;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = _tmp11_.red;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = line_color;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = _tmp13_.green;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp15_ = line_color;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = _tmp15_.blue;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp17_ = line_color;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp18_ = _tmp17_.alpha;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	cairo_set_source_rgba (_tmp10_, _tmp12_, _tmp14_, _tmp16_, _tmp18_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp19_ = ct;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	cairo_set_line_width (_tmp19_, (gdouble) 4);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20_ = self->priv->index;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp20_ > 0) {
#line 677 "snapshot-list-row.c"
		cairo_t* _tmp21_ = NULL;
		gint _tmp22_ = 0;
		cairo_t* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		cairo_t* _tmp26_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp21_ = ct;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp22_ = height;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_move_to (_tmp21_, (_tmp22_ / 2.0) + 0.5, (gdouble) (-1));
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp23_ = ct;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp24_ = height;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp25_ = height;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_line_to (_tmp23_, (_tmp24_ / 2.0) + 0.5, _tmp25_ / 2.0);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp26_ = ct;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_stroke (_tmp26_);
#line 702 "snapshot-list-row.c"
	}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp27_ = self->priv->index;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp28_ = self->priv->parent_size;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp27_ < (_tmp28_ - 1)) {
#line 710 "snapshot-list-row.c"
		cairo_t* _tmp29_ = NULL;
		gint _tmp30_ = 0;
		gint _tmp31_ = 0;
		cairo_t* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		cairo_t* _tmp35_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp29_ = ct;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp30_ = height;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp31_ = height;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_move_to (_tmp29_, (_tmp30_ / 2.0) + 0.5, _tmp31_ / 2.0);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp32_ = ct;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp33_ = height;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp34_ = height;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_line_to (_tmp32_, (_tmp33_ / 2.0) + 0.5, (gdouble) (_tmp34_ + 1));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp35_ = ct;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		cairo_stroke (_tmp35_);
#line 738 "snapshot-list-row.c"
	}
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	is_current = FALSE;
#line 742 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp36_ = self->snapshot;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_get_is_current (_tmp36_, (guint) 0, &_tmp37_, &_inner_error_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		is_current = _tmp37_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 754 "snapshot-list-row.c"
			goto __catch127_g_error;
		}
	}
	goto __finally127;
	__catch127_g_error:
	{
		GError* e = NULL;
		GError* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp38_ = e;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp39_ = _tmp38_->message;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:105: %s", _tmp39_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 776 "snapshot-list-row.c"
	}
	__finally127:
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (sc);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return FALSE;
#line 789 "snapshot-list-row.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp40_ = is_current;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp40_) {
#line 795 "snapshot-list-row.c"
		GtkStyleContext* _tmp41_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp41_ = sc;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_style_context_add_class (_tmp41_, "active");
#line 801 "snapshot-list-row.c"
	}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp42_ = ct;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	cairo_save (_tmp42_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp43_ = sc;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp44_ = ct;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp45_ = height;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp46_ = height;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp47_ = indicator_size;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp48_ = indicator_size;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_render_background (_tmp43_, _tmp44_, _tmp45_ / 4.0, _tmp46_ / 4.0, _tmp47_, _tmp48_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp49_ = sc;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp50_ = ct;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp51_ = height;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp52_ = height;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp53_ = indicator_size;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp54_ = indicator_size;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_render_frame (_tmp49_, _tmp50_, _tmp51_ / 4.0, _tmp52_ / 4.0, _tmp53_, _tmp54_ + 0.5);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp55_ = ct;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	cairo_restore (_tmp55_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp56_ = sc;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_restore (_tmp56_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	result = TRUE;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (sc);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return result;
#line 849 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_on_save_name_button_clicked (BoxesSnapshotListRow* self) {
	GError * _inner_error_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 857 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* config = NULL;
		GVirDomainSnapshot* _tmp0_ = NULL;
		GVirConfigDomainSnapshot* _tmp1_ = NULL;
		GVirConfigDomainSnapshot* _tmp2_ = NULL;
		GtkEntry* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GVirDomainSnapshot* _tmp6_ = NULL;
		GVirConfigDomainSnapshot* _tmp7_ = NULL;
		GtkLabel* _tmp8_ = NULL;
		GtkEntry* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		GtkStack* _tmp11_ = NULL;
		GtkBox* _tmp12_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = self->snapshot;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = gvir_domain_snapshot_get_config (_tmp0_, (guint) 0, &_inner_error_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		config = _tmp1_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 881 "snapshot-list-row.c"
			goto __catch128_g_error;
		}
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = config;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->priv->name_entry;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gtk_entry_get_text (_tmp3_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = _tmp4_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gvir_config_domain_snapshot_set_description (_tmp2_, _tmp5_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = self->snapshot;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = config;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_set_config (_tmp6_, _tmp7_, &_inner_error_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
			_g_object_unref0 (config);
#line 904 "snapshot-list-row.c"
			goto __catch128_g_error;
		}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = self->priv->name_label;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = self->priv->name_entry;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = gtk_entry_get_text (_tmp9_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_label_set_label (_tmp8_, _tmp10_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = self->priv->mode_stack;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp12_ = self->priv->show_name_box;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_stack_set_visible_child (_tmp11_, (GtkWidget*) _tmp12_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (config);
#line 923 "snapshot-list-row.c"
	}
	goto __finally128;
	__catch128_g_error:
	{
		GError* e = NULL;
		GError* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp13_ = e;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp14_ = _tmp13_->message;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:130: %s", _tmp14_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 943 "snapshot-list-row.c"
	}
	__finally128:
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 954 "snapshot-list-row.c"
	}
}


static void _boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_on_save_name_button_clicked ((BoxesSnapshotListRow*) self);
#line 962 "snapshot-list-row.c"
}


static Block92Data* block92_data_ref (Block92Data* _data92_) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_atomic_int_inc (&_data92_->_ref_count_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return _data92_;
#line 971 "snapshot-list-row.c"
}


static void block92_data_unref (void * _userdata_) {
	Block92Data* _data92_;
	_data92_ = (Block92Data*) _userdata_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (g_atomic_int_dec_and_test (&_data92_->_ref_count_)) {
#line 980 "snapshot-list-row.c"
		BoxesSnapshotListRow* self;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		self = _data92_->self;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (self);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_slice_free (Block92Data, _data92_);
#line 988 "snapshot-list-row.c"
	}
}


static Block93Data* block93_data_ref (Block93Data* _data93_) {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_atomic_int_inc (&_data93_->_ref_count_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return _data93_;
#line 998 "snapshot-list-row.c"
}


static void block93_data_unref (void * _userdata_) {
	Block93Data* _data93_;
	_data93_ = (Block93Data*) _userdata_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (g_atomic_int_dec_and_test (&_data93_->_ref_count_)) {
#line 1007 "snapshot-list-row.c"
		BoxesSnapshotListRow* self;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		self = _data93_->_data92_->self;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		block92_data_unref (_data93_->_data92_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_->_data92_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_slice_free (Block93Data, _data93_);
#line 1017 "snapshot-list-row.c"
	}
}


static void ___lambda136_ (Block93Data* _data93_) {
	Block92Data* _data92_;
	BoxesSnapshotListRow* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirDomain* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_ = _data93_->_data92_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = _data92_->self;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->machine;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_libvirt_machine_start (_tmp0_, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL, NULL);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = self->priv->machine;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _tmp2_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = _data93_->restart_id;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 1048 "snapshot-list-row.c"
}


static void ____lambda136__gvir_domain_stopped (GVirDomain* _sender, gpointer self) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	___lambda136_ (self);
#line 1055 "snapshot-list-row.c"
}


static void __lambda137_ (Block92Data* _data92_, GObject* obj, GAsyncResult* res) {
	BoxesSnapshotListRow* self;
	gboolean _tmp12_ = FALSE;
	GError * _inner_error_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = _data92_->self;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (res != NULL);
#line 1067 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		GtkContainer* _tmp2_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = self->snapshot;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = res;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_revert_to_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1080 "snapshot-list-row.c"
			goto __catch130_g_error;
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = self->priv->parent_container;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_widget_queue_draw ((GtkWidget*) _tmp2_);
#line 1087 "snapshot-list-row.c"
	}
	goto __finally130;
	__catch130_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		BoxesLibvirtMachine* _tmp5_ = NULL;
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesAppWindow* _tmp7_ = NULL;
		BoxesNotificationbar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		GdNotification* _tmp10_ = NULL;
		GdNotification* _tmp11_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = e;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = _tmp3_->message;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:162: %s", _tmp4_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = self->priv->machine;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = boxes_machine_get_window ((BoxesMachine*) _tmp5_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = _tmp6_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = _tmp7_->notificationbar;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = _ ("Failed to apply snapshot");
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = boxes_notificationbar_display_error (_tmp8_, _tmp9_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = _tmp10_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp11_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1130 "snapshot-list-row.c"
	}
	__finally130:
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1141 "snapshot-list-row.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = _data92_->show_activity;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp12_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		boxes_snapshot_list_row_set_activity_message (self, NULL);
#line 1149 "snapshot-list-row.c"
	}
}


static void ___lambda137__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	__lambda137_ (self, source_object, res);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	block92_data_unref (self);
#line 1159 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_revert_to_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	Block92Data* _data92_;
	gchar* snapshot_name = NULL;
	GVirDomainSnapshot* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GVirConfigDomainSnapshotDomainState snapshot_state = 0;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	BoxesMachineMachineState _tmp9_ = 0;
	BoxesMachineMachineState _tmp10_ = 0;
	gboolean _tmp11_ = FALSE;
	GVirConfigDomainSnapshotDomainState _tmp16_ = 0;
	GVirDomainSnapshot* _tmp21_ = NULL;
	GError * _inner_error_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_ = g_slice_new0 (Block92Data);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_->_ref_count_ = 1;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_->self = g_object_ref (self);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gvir_domain_snapshot_get_name (_tmp0_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_name = _tmp2_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_state = GVIR_CONFIG_DOMAIN_SNAPSHOT_DOMAIN_STATE_NOSTATE;
#line 1197 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* snapshot_config = NULL;
		GVirDomainSnapshot* _tmp3_ = NULL;
		GVirConfigDomainSnapshot* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		GVirConfigDomainSnapshotDomainState _tmp7_ = 0;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_config (_tmp3_, (guint) 0, &_inner_error_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_config = _tmp4_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1213 "snapshot-list-row.c"
			goto __catch129_g_error;
		}
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = gvir_config_domain_snapshot_get_description (snapshot_config);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_name);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_name = _tmp6_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = gvir_config_domain_snapshot_get_state (snapshot_config);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_state = _tmp7_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (snapshot_config);
#line 1230 "snapshot-list-row.c"
	}
	goto __finally129;
	__catch129_g_error:
	{
		GError* e = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1242 "snapshot-list-row.c"
	}
	__finally129:
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_name);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		block92_data_unref (_data92_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data92_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1259 "snapshot-list-row.c"
	}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = self->priv->machine;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp9_ = boxes_machine_get_state ((BoxesMachine*) _tmp8_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = _tmp9_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_->show_activity = _tmp10_ == BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp11_ = _data92_->show_activity;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp11_) {
#line 1273 "snapshot-list-row.c"
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp12_ = _ ("Reverting to %s…");
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp13_ = snapshot_name;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp14_ = g_strdup_printf (_tmp12_, _tmp13_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp15_ = _tmp14_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		boxes_snapshot_list_row_set_activity_message (self, _tmp15_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (_tmp15_);
#line 1290 "snapshot-list-row.c"
	}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = snapshot_state;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp16_ == GVIR_CONFIG_DOMAIN_SNAPSHOT_DOMAIN_STATE_SHUTOFF) {
#line 1296 "snapshot-list-row.c"
		Block93Data* _data93_;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		gulong _tmp20_ = 0UL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_ = g_slice_new0 (Block93Data);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_->_ref_count_ = 1;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_->_data92_ = block92_data_ref (_data92_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_->restart_id = (gulong) 0;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp17_ = self->priv->machine;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp19_ = _tmp18_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp20_ = g_signal_connect_data (_tmp19_, "stopped", (GCallback) ____lambda136__gvir_domain_stopped, block93_data_ref (_data93_), (GClosureNotify) block93_data_unref, 0);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_->restart_id = _tmp20_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		block93_data_unref (_data93_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_data93_ = NULL;
#line 1324 "snapshot-list-row.c"
	}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21_ = self->snapshot;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gvir_domain_snapshot_revert_to_async (_tmp21_, (guint) 0, NULL, ___lambda137__gasync_ready_callback, block92_data_ref (_data92_));
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (snapshot_name);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	block92_data_unref (_data92_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_data92_ = NULL;
#line 1336 "snapshot-list-row.c"
}


static void __lambda138_ (BoxesSnapshotListRow* self) {
	GtkContainer* _tmp0_ = NULL;
	GtkRevealer* _tmp1_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->parent_container;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_container_add (_tmp0_, (GtkWidget*) self);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_set_visible ((GtkWidget*) self, TRUE);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = self->priv->delete_revealer;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_revealer_set_reveal_child (_tmp1_, TRUE);
#line 1353 "snapshot-list-row.c"
}


static void ___lambda138__boxes_notification_ok_func (gpointer self) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	__lambda138_ ((BoxesSnapshotListRow*) self);
#line 1360 "snapshot-list-row.c"
}


static void __lambda140_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (res != NULL);
#line 1368 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		GtkContainer* _tmp2_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = self->snapshot;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = res;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_delete_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1381 "snapshot-list-row.c"
			goto __catch132_g_error;
		}
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = self->priv->parent_container;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		gtk_widget_queue_draw ((GtkWidget*) _tmp2_);
#line 1388 "snapshot-list-row.c"
	}
	goto __finally132;
	__catch132_g_error:
	{
		GError* e = NULL;
		GVirDomainSnapshot* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_name (_tmp3_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = e;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = _tmp5_->message;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:196: Error while deleting snapshot %s: %s", _tmp4_, _tmp6_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1414 "snapshot-list-row.c"
	}
	__finally132:
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1425 "snapshot-list-row.c"
	}
}


static void ___lambda140__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	__lambda140_ ((BoxesSnapshotListRow*) self, source_object, res);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_object_unref (self);
#line 1435 "snapshot-list-row.c"
}


static void __lambda139_ (BoxesSnapshotListRow* self) {
	GVirDomainSnapshot* _tmp0_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gvir_domain_snapshot_delete_async (_tmp0_, (guint) 0, NULL, ___lambda140__gasync_ready_callback, g_object_ref (self));
#line 1445 "snapshot-list-row.c"
}


static void ___lambda139__boxes_notification_cancel_func (gpointer self) {
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	__lambda139_ ((BoxesSnapshotListRow*) self);
#line 1452 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_delete_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	gchar* snapshot_identifier = NULL;
	GVirDomainSnapshot* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* message = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GtkRevealer* _tmp14_ = NULL;
	BoxesNotificationOKFunc undo = NULL;
	void* undo_target = NULL;
	GDestroyNotify undo_target_destroy_notify = NULL;
	BoxesNotificationCancelFunc really_remove = NULL;
	void* really_remove_target = NULL;
	GDestroyNotify really_remove_target_destroy_notify = NULL;
	BoxesLibvirtMachine* _tmp15_ = NULL;
	BoxesAppWindow* _tmp16_ = NULL;
	BoxesAppWindow* _tmp17_ = NULL;
	BoxesNotificationbar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	BoxesNotificationOKFunc _tmp20_ = NULL;
	void* _tmp20__target = NULL;
	GDestroyNotify _tmp20__target_destroy_notify = NULL;
	BoxesNotificationCancelFunc _tmp21_ = NULL;
	void* _tmp21__target = NULL;
	GDestroyNotify _tmp21__target_destroy_notify = NULL;
	GdNotification* _tmp22_ = NULL;
	GdNotification* _tmp23_ = NULL;
	GError * _inner_error_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gvir_domain_snapshot_get_name (_tmp0_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_identifier = _tmp2_;
#line 1498 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* config = NULL;
		GVirDomainSnapshot* _tmp3_ = NULL;
		GVirConfigDomainSnapshot* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_config (_tmp3_, (guint) 0, &_inner_error_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		config = _tmp4_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1513 "snapshot-list-row.c"
			goto __catch131_g_error;
		}
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = gvir_config_domain_snapshot_get_description (config);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_identifier);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_identifier = _tmp6_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (config);
#line 1526 "snapshot-list-row.c"
	}
	goto __finally131;
	__catch131_g_error:
	{
		GError* e = NULL;
		GVirDomainSnapshot* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = self->snapshot;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = gvir_domain_snapshot_get_name (_tmp7_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = e;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = _tmp9_->message;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:177: Could not get configuration of snapshot %s" \
": %s", _tmp8_, _tmp10_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1552 "snapshot-list-row.c"
	}
	__finally131:
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_identifier);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1565 "snapshot-list-row.c"
	}
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp11_ = _ ("Snapshot \"%s\" deleted.");
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = snapshot_identifier;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = g_strdup_printf (_tmp11_, _tmp12_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	message = _tmp13_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = self->priv->delete_revealer;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_revealer_set_reveal_child (_tmp14_, FALSE);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo = ___lambda138__boxes_notification_ok_func;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo_target = g_object_ref (self);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = g_object_unref;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove = ___lambda139__boxes_notification_cancel_func;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target = g_object_ref (self);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = g_object_unref;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp15_ = self->priv->machine;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = boxes_machine_get_window ((BoxesMachine*) _tmp15_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp17_ = _tmp16_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp18_ = _tmp17_->notificationbar;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp19_ = _ ("_Undo");
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20_ = undo;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20__target = undo_target;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20__target_destroy_notify = undo_target_destroy_notify;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21_ = really_remove;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21__target = really_remove_target;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21__target_destroy_notify = really_remove_target_destroy_notify;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp22_ = boxes_notificationbar_display_for_action (_tmp18_, message, _tmp19_, _tmp20_, _tmp20__target, _tmp20__target_destroy_notify, _tmp21_, _tmp21__target, _tmp21__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp23_ = _tmp22_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (_tmp23_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	(really_remove_target_destroy_notify == NULL) ? NULL : (really_remove_target_destroy_notify (really_remove_target), NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	(undo_target_destroy_notify == NULL) ? NULL : (undo_target_destroy_notify (undo_target), NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo_target = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (message);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (snapshot_identifier);
#line 1643 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_rename_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	GtkEntry* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkStack* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkEntry* _tmp5_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->name_entry;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = self->priv->name_label;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = gtk_label_get_text (_tmp1_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_entry_set_text (_tmp0_, _tmp2_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = self->priv->mode_stack;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = self->priv->edit_name_box;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_stack_set_visible_child (_tmp3_, (GtkWidget*) _tmp4_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = self->priv->name_entry;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp5_);
#line 1676 "snapshot-list-row.c"
}


void boxes_snapshot_list_row_unreveal (BoxesSnapshotListRow* self) {
	GtkRevealer* _tmp0_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->delete_revealer;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_revealer_set_reveal_child (_tmp0_, FALSE);
#line 1688 "snapshot-list-row.c"
}


void boxes_snapshot_list_row_reveal (BoxesSnapshotListRow* self) {
	GtkRevealer* _tmp0_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->delete_revealer;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_revealer_set_reveal_child (_tmp0_, TRUE);
#line 1700 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_update_index (BoxesSnapshotListRow* self) {
	GtkContainer* parent = NULL;
	GtkContainer* _tmp0_ = NULL;
	GtkContainer* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GtkContainer* _tmp3_ = NULL;
	GList* siblings = NULL;
	GtkContainer* _tmp5_ = NULL;
	GList* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	GList* _tmp9_ = NULL;
	guint _tmp10_ = 0U;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	parent = _tmp1_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = parent;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp3_ == NULL) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = TRUE;
#line 1731 "snapshot-list-row.c"
	} else {
		GtkContainer* _tmp4_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = parent;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = !G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_list_box_get_type ());
#line 1738 "snapshot-list-row.c"
	}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp2_) {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (parent);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1746 "snapshot-list-row.c"
	}
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = parent;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp6_ = gtk_container_get_children (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp5_) : NULL);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	siblings = _tmp6_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp7_ = siblings;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = g_list_index (_tmp7_, (GtkWidget*) self);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->index = _tmp8_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp9_ = siblings;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = g_list_length (_tmp9_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_size = (gint) _tmp10_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_list_free0 (siblings);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (parent);
#line 1770 "snapshot-list-row.c"
}


const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->_activity_message;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return result;
#line 1785 "snapshot-list-row.c"
}


void boxes_snapshot_list_row_set_activity_message (BoxesSnapshotListRow* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (self->priv->_activity_message);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->_activity_message = _tmp1_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_object_notify ((GObject *) self, "activity-message");
#line 1804 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_update_index_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index ((BoxesSnapshotListRow*) self);
#line 1811 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_update_index_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index ((BoxesSnapshotListRow*) self);
#line 1818 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row___lambda142_ (BoxesSnapshotListRow* self) {
	GtkContainer* parent = NULL;
	GtkContainer* _tmp0_ = NULL;
	GtkContainer* _tmp1_ = NULL;
	GtkContainer* _tmp2_ = NULL;
	GtkContainer* _tmp3_ = NULL;
	GtkContainer* _tmp4_ = NULL;
	GtkContainer* _tmp5_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp0_) : NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	parent = _tmp1_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = parent;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp2_ == NULL) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (parent);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1844 "snapshot-list-row.c"
	}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = parent;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_container = _tmp3_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index (self);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = parent;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object (_tmp4_, "add", (GCallback) _boxes_snapshot_list_row_update_index_gtk_container_add, self, 0);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = parent;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object (_tmp5_, "remove", (GCallback) _boxes_snapshot_list_row_update_index_gtk_container_remove, self, 0);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (parent);
#line 1862 "snapshot-list-row.c"
}


static void __boxes_snapshot_list_row___lambda142__gtk_widget_parent_set (GtkWidget* _sender, GtkWidget* previous_parent, gpointer self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_boxes_snapshot_list_row___lambda142_ ((BoxesSnapshotListRow*) self);
#line 1869 "snapshot-list-row.c"
}


static GObject * boxes_snapshot_list_row_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSnapshotListRow * self;
	GtkStyleContext* _tmp0_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	parent_class = G_OBJECT_CLASS (boxes_snapshot_list_row_parent_class);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-snapshot-list-row");
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object ((GtkWidget*) self, "parent-set", (GCallback) __boxes_snapshot_list_row___lambda142__gtk_widget_parent_set, self, 0);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_list_box_row_set_selectable ((GtkListBoxRow*) self, FALSE);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	return obj;
#line 1896 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_class_init (BoxesSnapshotListRowClass * klass) {
	gint BoxesSnapshotListRow_private_offset;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_type_class_add_private (klass, sizeof (BoxesSnapshotListRowPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	((GtkWidgetClass *) klass)->draw = boxes_snapshot_list_row_real_draw;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_snapshot_list_row_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_snapshot_list_row_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_snapshot_list_row_constructor;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_snapshot_list_row_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE, g_param_spec_string ("activity-message", "activity-message", "activity-message", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	BoxesSnapshotListRow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/snapshot-list-row.ui");
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "delete_revealer", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, delete_revealer));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "name_label", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, name_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "mode_stack", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, mode_stack));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "name_entry", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, name_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "edit_name_box", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, edit_name_box));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "show_name_box", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, show_name_box));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_save_name_button_clicked", G_CALLBACK(_boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked));
#line 1936 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_instance_init (BoxesSnapshotListRow * self) {
	gchar* _tmp0_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv = BOXES_SNAPSHOT_LIST_ROW_GET_PRIVATE (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = g_strdup ("");
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->_activity_message = _tmp0_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_container = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1952 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_finalize (GObject* obj) {
	BoxesSnapshotListRow * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->snapshot);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (self->priv->_activity_message);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->delete_revealer);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->name_label);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->mode_stack);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->name_entry);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->edit_name_box);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->show_name_box);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->machine);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (boxes_snapshot_list_row_parent_class)->finalize (obj);
#line 1980 "snapshot-list-row.c"
}


GType boxes_snapshot_list_row_get_type (void) {
	static volatile gsize boxes_snapshot_list_row_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_snapshot_list_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSnapshotListRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_snapshot_list_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSnapshotListRow), 0, (GInstanceInitFunc) boxes_snapshot_list_row_instance_init, NULL };
		GType boxes_snapshot_list_row_type_id;
		boxes_snapshot_list_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesSnapshotListRow", &g_define_type_info, 0);
		g_once_init_leave (&boxes_snapshot_list_row_type_id__volatile, boxes_snapshot_list_row_type_id);
	}
	return boxes_snapshot_list_row_type_id__volatile;
}


static void _vala_boxes_snapshot_list_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSnapshotListRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		case BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		g_value_set_string (value, boxes_snapshot_list_row_get_activity_message (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 2007 "snapshot-list-row.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 2013 "snapshot-list-row.c"
	}
}


static void _vala_boxes_snapshot_list_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSnapshotListRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		case BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		boxes_snapshot_list_row_set_activity_message (self, g_value_get_string (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 2029 "snapshot-list-row.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 2035 "snapshot-list-row.c"
	}
}



